import json
import os
import boto3
from cs_ai_common.s3.utils import get_bucket_name_from_arn


BUCKET_NAME = get_bucket_name_from_arn(os.getenv("RESULTS_BUCKET_NAME", None))

def write_result_to_s3(result: dict, key: str, bucket_name: str | None = None) -> None:
    s3 = boto3.client('s3')
    object_key = key
    _bucket_name = bucket_name if bucket_name is not None else BUCKET_NAME
    response = s3.put_object(
        Body=json.dumps(result),
        Bucket=_bucket_name,
        Key=object_key
    )
    return response


import os
from cs_ai_common.s3.resolver_results import write_result_to_s3
from cs_ai_common.resolver_cache.s3_cache_utils import save_cache_result
from cs_ai_common.s3.utils import get_bucket_name_from_arn
from cs_ai_common.services.result_writer_service import ResultWriterService


class S3WriterService(ResultWriterService): 
    def write_result(self, content: dict, key: str) -> None:
        write_result_to_s3(content, key)
    
    def write_cache(self, content: dict, key: str, resolver_name: str) -> None:
        bucket_name = get_bucket_name_from_arn(os.getenv("CACHE_BUCKET_NAME", None))
        save_cache_result(key, resolver_name, content, bucket_name)